@@ -1,7 +1,7 @@
 class TestImport():
 
     def test_imports(self):
-        from xgpy.Utility import Utility
+        from xgpy.utility import Utility
         from xgpy.understat import UnderstatPlayer
 
         assert 1 == 1
